@@ -1,5 +1,5 @@
 import sqlite3
-from .exceptions import ConventionViolationError
+from .exceptions import ConventionViolationError, CustomSQLBuildError
 from .utils import CustomQuery, Field, is_empty_function
 
 
@@ -154,37 +154,70 @@ class DAOMeta(type):
                     sql_query_template = ''
                     lexems = attr_name[4:].split('_')
                     sep = ' '
+                    final_user_lex = ''
+
+                    def complete_custom_injection():
+                        nonlocal sql_query_template, final_user_lex
+                        if len(final_user_lex) != 0:
+                            sql_query_template += f"{final_user_lex}"
+                            correspondent_fields = [f for f in dct['MODEL'].FIELDS if f.name == final_user_lex]
+                            if len(correspondent_fields) == 0:
+                                raise CustomSQLBuildError
+                            correspondent_field = correspondent_fields[0]
+                            if correspondent_field.dtype == 'text':
+                                sql_query_template += f" = '{{{final_user_lex}}}' "
+                            else:
+                                sql_query_template += f" = {{{final_user_lex}}} "
+                            keys.append(final_user_lex)
+                            final_user_lex = ''
+
                     for i, lex in enumerate(lexems):
                         if lex == 'select' or lex == 'find':
                             sep = ','
+                            complete_custom_injection()
                             sql_query_template += 'SELECT '
                         elif lex == 'all':
                             sep = ' '
+                            complete_custom_injection()
                             if lexems[0].upper() != 'DELETE':
                                 sql_query_template += '*' + sep
                                 sql_query_template += f"FROM {dct['MODEL'].NAME}" + sep
                         elif lex == 'by':
                             sep = ' '
+                            complete_custom_injection()
                             sql_query_template += 'WHERE' + sep
                         elif lex == 'and':
                             sep = ' '
+                            complete_custom_injection()
                             sql_query_template += 'AND' + sep
                         elif lex == 'delete':
                             sep = ' '
+                            complete_custom_injection()
                             sql_query_template += f"DELETE FROM {dct['MODEL'].NAME} "
                         else:
-                            if sql_query_template[-1] != sep:
-                                sql_query_template += sep
-                            sql_query_template += lex + ' = {}'
-                            keys.append(lex)
+                            if len(final_user_lex) != 0:
+                                final_user_lex += '_'
+                            final_user_lex += lex
 
-                    @staticmethod
-                    def sql_custom_query(*args, **kwargs):
-                        sql_query = sql_query_template
-                        for key in keys:
-                            sql_query = sql_query.format(kwargs[key])
-                        return sql_query
-                    setattr(cls, attr_name, sql_custom_query)
+                    complete_custom_injection()
+                    sql_query_template = sql_query_template.rstrip()
+
+                    def sql_custom_query_factory(sql_query_template, keys):
+                        @staticmethod
+                        def sql_custom_query(*args, **kwargs):
+                            sql_query = sql_query_template
+                            sql_query = sql_query.format(**kwargs)
+                            return sql_query
+                        return sql_custom_query
+
+                    setattr(
+                        cls,
+                        attr_name,
+                        sql_custom_query_factory(
+                            sql_query_template,
+                            keys
+                        )
+                    )
                 elif dct[attr_name].query is not None:
                     @staticmethod
                     def sql_custom_query(*args):
